@@ -5,7 +5,7 @@ use warnings;
 use namespace::autoclean;
 use autodie;
 
-our $VERSION = '0.200000';
+our $VERSION = '0.200001';
 
 use IO::Handle;
 use Math::Int64 0.51;
@@ -469,7 +469,7 @@ MaxMind::DB::Writer::Tree - Tree representing a MaxMind DB database in memory -
 
 =head1 VERSION
 
-version 0.200000
+version 0.200001
 
 =head1 SYNOPSIS
 
@@ -678,11 +678,12 @@ This is the 6to4 range
 
 =back
 
+When aliasing is enabled, insertions into the aliased locations will throw an
+exception. To insert an IPv4 address, insert it using IPv4 notation or insert
+directly into ::/96.
+
 Aliased nodes are I<not> followed when merging nodes. Only merges into the
-original IPv4 location, ::/96, will be followed. This only affects insertions
-of networks containing the complete aliased network. Insertions within the
-aliased network will be merged, whether they use the original location or any
-of the aliases.
+original IPv4 location, ::/96, will be followed.
 
 This parameter is optional. It defaults to false.
 
